You are viewing a plain text version of this content. The canonical link for it is here.
Posted to jcs-dev@jakarta.apache.org by as...@apache.org on 2006/02/05 19:48:40 UTC

svn commit: r375078 - in /jakarta/jcs/trunk/src: java/org/apache/jcs/config/ java/org/apache/jcs/engine/ java/org/apache/jcs/engine/control/ java/org/apache/jcs/engine/memory/ java/org/apache/jcs/engine/memory/lru/ java/org/apache/jcs/engine/memory/mru...

Author: asmuts
Date: Sun Feb  5 10:48:38 2006
New Revision: 375078

URL: http://svn.apache.org/viewcvs?rev=375078&view=rev
Log: (empty)

Added:
    jakarta/jcs/trunk/src/scripts/remoteCacheStats.sh
Modified:
    jakarta/jcs/trunk/src/java/org/apache/jcs/config/PropertySetterException.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/Attributes.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheAdaptor.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheConstants.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheDescriptor.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheElement.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheEventQueue.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheGroup.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheInfo.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheUtils.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CompositeCacheAttributes.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/ElementAttributes.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/PooledCacheEventQueue.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/ZombieCacheService.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCache.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCacheConfigurator.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCacheManager.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/AbstractMemoryCache.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/lru/LRUMemoryCache.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/mru/MRUMemoryCache.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/DoubleLinkedList.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/DoubleLinkedListNode.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/MemoryElementDescriptor.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/stats/CacheStats.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/stats/Stats.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/config/IUtilConstants.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/data/PropertyGroups.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/props/PropertyLoader.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/struct/LRUElementDescriptor.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/PoolConfiguration.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/ThreadPool.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/ThreadPoolManager.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/behavior/IPoolConfiguration.java
    jakarta/jcs/trunk/src/test-conf/log4j.properties

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/config/PropertySetterException.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/config/PropertySetterException.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/config/PropertySetterException.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/config/PropertySetterException.java Sun Feb  5 10:48:38 2006
@@ -31,6 +31,8 @@
 public class PropertySetterException
     extends Exception
 {
+    private static final long serialVersionUID = -210271658004609028L;
+
     /** Description of the Field */
     protected Throwable rootCause;
 

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/Attributes.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/Attributes.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/Attributes.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/Attributes.java Sun Feb  5 10:48:38 2006
@@ -33,52 +33,32 @@
     implements IAttributes, Serializable, Cloneable
 {
 
+    private static final long serialVersionUID = 2245148271982787250L;
+
     // too slow to be private
-    // need direct access
-    // remove
-    /** Description of the Field */
+    // need direct access for performance.
+    
+    /** Can this be send over a lateral or remote service. */
     public boolean IS_DISTRIBUTE = false;
 
-    // lateral
-
-    /** Description of the Field */
+    /** Can the element be set laterally */
     public boolean IS_LATERAL = false;
 
-    // lateral
-    /** Description of the Field */
-    public boolean IS_NOFLUSH = false;
-
-    /** Description of the Field */
-    public boolean IS_REPLY = false;
-
-    /** Description of the Field */
-    public boolean IS_SYNCHRONIZE = false;
-
-    /** Description of the Field */
+    /** Can the element be spooled to disk. */
     public boolean IS_SPOOL = false;
 
     /** Description of the Field */
-    public boolean IS_GROUP_TTL_DESTROY = false;
-
-    /** Description of the Field */
-    public boolean IS_ORIGINAL = false;
-
-    /** Description of the Field */
     public boolean IS_REMOTE = false;
 
-    // central rmi store
-    /** Description of the Field */
+    /** Is the attribute above the max life law. */
     public boolean IS_ETERNAL = true;
 
-    //false; // can turn off expiration
-
     /** Description of the Field */
     public long version = 0;
 
     /** Description of the Field */
     public long ttl = 0;
 
-    // timetolive
     /** Description of the Field */
     public long default_ttl = 0;
 
@@ -94,7 +74,9 @@
     /** Description of the Field */
     public long createTime = 0;
 
-    /** Constructor for the Attributes object */
+    /** 
+     * Set the create time.
+     */
     public Attributes()
     {
         this.createTime = System.currentTimeMillis();
@@ -107,14 +89,7 @@
      */
     protected Attributes( Attributes attr )
     {
-
-        IS_NOFLUSH = attr.IS_NOFLUSH;
-        IS_REPLY = attr.IS_REPLY;
-        IS_SYNCHRONIZE = attr.IS_SYNCHRONIZE;
-        IS_GROUP_TTL_DESTROY = attr.IS_GROUP_TTL_DESTROY;
         IS_ETERNAL = attr.IS_ETERNAL;
-        // central rmi store
-        IS_ORIGINAL = attr.IS_ORIGINAL;
 
         IS_SPOOL = attr.IS_SPOOL;
         // waterfal onto disk, for pure disk set memory to 0
@@ -133,7 +108,6 @@
 
     }
 
-    //public Object clone () {
     /**
      * clone
      * @return Attributes
@@ -159,7 +133,6 @@
      */
     public Object clone2()
     {
-
         try
         {
             ByteArrayOutputStream baos = new ByteArrayOutputStream( 100 );
@@ -169,7 +142,6 @@
             oos.close();
 
             // deserialize byte array into ArrayList
-
             ByteArrayInputStream bais = new ByteArrayInputStream( buf );
             ObjectInputStream ois = new ObjectInputStream( bais );
             Attributes attr = (Attributes) ois.readObject();
@@ -180,12 +152,9 @@
         }
         catch ( Exception e )
         {
+            // swallow
         }
         return null;
-        /*
-         * System.out.println( "cloning" ); Attributes attr = new Attributes(
-         * this ); return attr;
-         */
     }
 
     /**
@@ -210,16 +179,6 @@
         this.ttl = ttl;
     }
 
-    //    /**
-    //     * Sets the defaultTimeToLive attribute of the Attributes object
-    //     *
-    //     * @param ttl The new defaultTimeToLive value
-    //     */
-    //    public void setDefaultTimeToLive( long ttl )
-    //    {
-    //        this.default_ttl = ttl;
-    //    }
-
     /**
      * Sets the idleTime attribute of the Attributes object
      * 
@@ -231,8 +190,6 @@
         this.idle = idle;
     }
 
-    //public void setListener( int event, CacheEventListener listerner) {}
-
     /**
      * Size in bytes.
      * 
@@ -307,15 +264,6 @@
         return this.ttl;
     }
 
-    // NOT NECESSARY will be using max life not time left pattern
-    //    /** Description of the Method */
-    //    public long timeToSeconds( int days, int hours, int minutes, int seconds
-    // )
-    //        throws InvalidArgumentException
-    //    {
-    //        return 5;
-    //    }
-
     /*
      * 
      */
@@ -329,11 +277,5 @@
             .append( String.valueOf( createTime ) ).append( " ]" );
 
         return dump.toString();
-        //dump.append( " IS_NOFLUSH = " + IS_NOFLUSH + "\n");
-        //dump.append( " IS_REPLY = " + IS_REPLY + "\n");
-        //dump.append( " IS_SYNCHRONIZE = " + IS_SYNCHRONIZE + "\n");
-        //dump.append( " IS_GROUP_TTL_DESTROY = " + IS_GROUP_TTL_DESTROY +
-        // "\n");
-        //dump.append( " IS_ORIGINAL = " + IS_ORIGINAL + "\n");
     }
 }

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheAdaptor.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheAdaptor.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheAdaptor.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheAdaptor.java Sun Feb  5 10:48:38 2006
@@ -94,7 +94,7 @@
         }
         catch ( Exception e )
         {
-
+            // swallow
         }
     }
 

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheConstants.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheConstants.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheConstants.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheConstants.java Sun Feb  5 10:48:38 2006
@@ -23,6 +23,7 @@
  */
 public interface CacheConstants
 {
+    /** This is the name of the config file that we will look for by default. */
     public static final String DEFAULT_CONFIG = "/cache.ccf";
 
     /** Cache alive status. */
@@ -34,6 +35,6 @@
     /** Cache in error. */
     public final static int STATUS_ERROR = 3;
 
-    /** Delimiter of a cache name component. */
+    /** Delimiter of a cache name component. This is used for hierarchical deletion */
     public final static String NAME_COMPONENT_DELIMITER = ":";
 }

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheDescriptor.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheDescriptor.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheDescriptor.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheDescriptor.java Sun Feb  5 10:48:38 2006
@@ -28,12 +28,9 @@
 public class CacheDescriptor
 {
 
-    /** Description of the Field */
+    /** This is the auxiliary that will do the work. */
     public final ICache cache;
 
-    /*
-     * Map ICacheListener to ICacheEventQueue.
-     */
     /** Description of the Field */
     public final Map eventQMap = new Hashtable();
 
@@ -51,5 +48,4 @@
         this.cache = cache;
     }
 
-}
-// end class
+}
\ No newline at end of file

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheElement.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheElement.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheElement.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheElement.java Sun Feb  5 10:48:38 2006
@@ -18,33 +18,34 @@
 
 import java.io.Serializable;
 
-import org.apache.jcs.engine.behavior.IElementAttributes;
-
 import org.apache.jcs.engine.behavior.ICacheElement;
+import org.apache.jcs.engine.behavior.IElementAttributes;
 
 /**
  * Generic element wrapper. Often stuffed inside another.
- *  
+ * 
  */
 public class CacheElement
     implements ICacheElement, Serializable
 {
 
-    /** Description of the Field */
+    private static final long serialVersionUID = -6062305728297627263L;
+
+    /** The name of the cache region. This is a namespace. */
     public final String cacheName;
 
-    /** Description of the Field */
+    /** This is the cache key by which the value can be referenced. */
     public final Serializable key;
 
-    /** Description of the Field */
+    /** This is the cached value, reference by the key. */
     public final Serializable val;
 
-    /** Description of the Field */
+    /**
+     * These attributes hold information about the element and what it is
+     * allowed to do.
+     */
     public ElementAttributes attr;
 
-    // make sure it is open for spooling?
-    //public boolean isLocked = false;
-
     /**
      * Constructor for the CacheElement object
      * 
@@ -139,16 +140,15 @@
     }
 
     /**
-     * For debuggin only.
+     * For debugging only.
      * 
      * @return String representation
-     *  
+     * 
      */
     public String toString()
     {
-        return "[cacheName=" + cacheName + ", key=" + key + ", val=" + val + ", attr = " + attr + "]";
+        return "[CacheElement: cacheName [" + cacheName + "], key [" + key + "], val [" + val + "], attr [" + attr
+            + "]";
     }
 
-}
-// end class
-
+}
\ No newline at end of file

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheEventQueue.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheEventQueue.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheEventQueue.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheEventQueue.java Sun Feb  5 10:48:38 2006
@@ -47,14 +47,14 @@
 {
     private static final Log log = LogFactory.getLog( CacheEventQueue.class );
 
-    // private LinkedQueue queue = new LinkedQueue();
-
     private static final int queueType = SINGLE_QUEUE_TYPE;
 
+    private static final int DEFAULT_WAIT_TO_DIE_MILLIS = 10000;
+    
     // time to wait for an event before snuffing the background thread
     // if the queue is empty.
     // make configurable later
-    private int waitToDieMillis = 10000;
+    private int waitToDieMillis = DEFAULT_WAIT_TO_DIE_MILLIS;
 
     private ICacheListener listener;
 
@@ -73,12 +73,8 @@
 
     private Thread processorThread;
 
-    // Internal queue implementation
-
     private Object queueLock = new Object();
 
-    // Dummy node
-
     private Node head = new Node();
 
     private Node tail = head;
@@ -159,7 +155,7 @@
     /**
      * Sets the time to wait for events before killing the background thread.
      * 
-     * @param wtdm,
+     * @param wtdm
      *            the ms for the q to sit idle.
      */
     public void setWaitToDieMillis( int wtdm )
@@ -475,12 +471,11 @@
         /**
          * Constructor for the QProcessor object
          * 
-         * @param aQueue,
+         * @param aQueue
          *            the event queue to take items from.
          */
         QProcessor( CacheEventQueue aQueue )
         {
-
             super( "CacheEventQueue.QProcessor-" + aQueue.cacheName );
 
             setDaemon( true );

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheGroup.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheGroup.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheGroup.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheGroup.java Sun Feb  5 10:48:38 2006
@@ -25,13 +25,13 @@
 public class CacheGroup
 {
 
-    //private Atrributes attr;
-    /** Description of the Field */
+    /** Element configuration. */
     public IElementAttributes attr;
 
     /** Constructor for the CacheGroup object */
     public CacheGroup()
     {
+        super();
     }
 
     /**

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheInfo.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheInfo.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheInfo.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheInfo.java Sun Feb  5 10:48:38 2006
@@ -22,13 +22,13 @@
  * A shared static variable holder for the lateral cache
  *  
  */
-public class CacheInfo
+public final class CacheInfo
 {
 
-    // shouldn't be instantiated
-    /** Constructor for the CacheInfo object */
+    /** shouldn't be instantiated */
     private CacheInfo()
     {
+        super();
     }
 
     /**

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheUtils.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheUtils.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheUtils.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheUtils.java Sun Feb  5 10:48:38 2006
@@ -24,17 +24,20 @@
 import java.io.Serializable;
 
 /**
+ * This will be superceded by the new pluggable serializer infastructure.
+ * 
  * basic utility functions
  * 
  * TODO move to util
  *  
  */
-public class CacheUtils
+public final class CacheUtils
 {
 
-    /** Constructor for the CacheUtils object */
+    /** No instances please. */
     private CacheUtils()
     {
+        super();
     }
 
     /** Returns a deeply cloned object. 

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CompositeCacheAttributes.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CompositeCacheAttributes.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CompositeCacheAttributes.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CompositeCacheAttributes.java Sun Feb  5 10:48:38 2006
@@ -19,40 +19,67 @@
 import org.apache.jcs.engine.behavior.ICompositeCacheAttributes;
 
 /**
- * Description of the Class
- *  
+ * The CompositeCacheAttributes defines the general cache region settings. If a
+ * region is not explicitly defined in the cache.ccf then it inherits the cache
+ * default settings.
+ * <p>
+ * If all the default attributes are not defined in the default region
+ * definition in the cache.ccf, the hard coded defaults will be used.
+ * 
  */
 public class CompositeCacheAttributes
     implements ICompositeCacheAttributes, Cloneable
 {
 
+    private static final long serialVersionUID = 6754049978134196787L;
+
     // Allows for programmatic stopping of configuration information. Shouldn't
     // use.
     // cannot turn on service if it is not set in props. Only stop.
-    private boolean useLateral = true;
+    private static final boolean DEFAULT_USE_LATERAL = true;
 
-    private boolean useRemote = true;
+    private static final boolean DEFAULT_USE_REMOTE = true;
 
-    private boolean useDisk = true;
+    private static final boolean DEFAULT_USE_DISK = true;
 
-    private boolean useMemoryShrinker = false;
+    private static final boolean DEFAULT_USE_SHRINKER = false;
 
-    private int maxObjs = 100;
+    private static final int DEFAULT_MAX_OBJECTS = 100;
 
-    /**
-     * maxMemoryIdleTimeSeconds
-     */
-    protected long maxMemoryIdleTimeSeconds = 60 * 120; // 2 hours
+    private static final int DEFAULT_MAX_MEMORY_IDLE_TIME_SECONDS = 60 * 120; // 2 hours
 
-    /**
-     * shrinkerIntervalSeconds
-     */
-    protected long shrinkerIntervalSeconds = 30;
+    private static final int DEFAULT_SHRINKER_INTERVAL_SECONDS = 30; 
+
+    private static final int DEFAULT_MAX_SPOOL_PER_RUN = -1; 
+
+    private static final String DEFAULT_MEMORY_CACHE_NAME = "org.apache.jcs.engine.memory.lru.LRUMemoryCache";
+    
+    private boolean useLateral = DEFAULT_USE_LATERAL;
 
-    protected int maxSpoolPerRun = -1;
+    private boolean useRemote = DEFAULT_USE_REMOTE;
 
+    /** Whether we should use a disk cache if it is configured. */
+    private boolean useDisk = DEFAULT_USE_DISK;
+
+    /** Whether or not we should run the memory shrinker thread. */
+    private boolean useMemoryShrinker = DEFAULT_USE_SHRINKER;
+
+    /** The maximum objects that the memory cache will be allowed to hold. */
+    private int maxObjs = DEFAULT_MAX_OBJECTS;
+
+    /** maxMemoryIdleTimeSeconds */
+    private long maxMemoryIdleTimeSeconds = DEFAULT_MAX_MEMORY_IDLE_TIME_SECONDS;
+
+    /** shrinkerIntervalSeconds  */
+    private long shrinkerIntervalSeconds = DEFAULT_SHRINKER_INTERVAL_SECONDS;
+
+    /** The maximum number the shrinker will spool to disk per run. */
+    private int maxSpoolPerRun = DEFAULT_MAX_SPOOL_PER_RUN;
+
+    /** The name of this cache region. */
     private String cacheName;
 
+    /** The name of the memory cache implementation class. */
     private String memoryCacheName;
 
     /**
@@ -60,8 +87,9 @@
      */
     public CompositeCacheAttributes()
     {
+        super();
         // set this as the default so the configuration is a bit simpler
-        memoryCacheName = "org.apache.jcs.engine.memory.lru.LRUMemoryCache";
+        memoryCacheName = DEFAULT_MEMORY_CACHE_NAME;
     }
 
     /**
@@ -293,11 +321,10 @@
         try
         {
             ICompositeCacheAttributes cattr = (CompositeCacheAttributes) this.clone();
-            //System.out.println( "cattr = " + cattr );
             return cattr;
         }
         catch ( Exception e )
-        {
+        {            
             System.err.println( e.toString() );
             return new CompositeCacheAttributes();
         }

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/ElementAttributes.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/ElementAttributes.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/ElementAttributes.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/ElementAttributes.java Sun Feb  5 10:48:38 2006
@@ -38,6 +38,8 @@
     implements IElementAttributes, Serializable, Cloneable
 {
 
+    private static final long serialVersionUID = 7814990748035017441L;
+
     /**
      * can this item be flushed to disk
      */
@@ -183,6 +185,7 @@
         }
         catch ( Exception e )
         {
+            // swallow
         }
         return null;
     }

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/PooledCacheEventQueue.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/PooledCacheEventQueue.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/PooledCacheEventQueue.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/PooledCacheEventQueue.java Sun Feb  5 10:48:38 2006
@@ -612,12 +612,12 @@
     }
 
     /**
-     * @param b,
+     * @param isWorkingArg
      *            whether the queue is functional
      */
-    public void setWorking( boolean b )
+    public void setWorking( boolean isWorkingArg )
     {
-        working = b;
+        working = isWorkingArg;
     }
 
     /**

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/ZombieCacheService.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/ZombieCacheService.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/ZombieCacheService.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/ZombieCacheService.java Sun Feb  5 10:48:38 2006
@@ -18,6 +18,8 @@
 
 import java.io.Serializable;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.apache.jcs.engine.behavior.ICacheElement;
 import org.apache.jcs.engine.behavior.ICacheService;
 
@@ -31,11 +33,20 @@
     implements ICacheService, IZombie
 {
 
-    /*
+    private static final Log log = LogFactory.getLog( ZombieCacheService.class );
+
+    
+    /**
      * 
+     * @param item
      */
     public void put( ICacheElement item )
     {
+        if ( log.isDebugEnabled() )
+        {
+            log.debug( "Zombie put for item " + item );
+        }
+        // zombies have no inner life
     }
 
     /*
@@ -44,6 +55,7 @@
      */
     public void update( ICacheElement item )
     {
+        // zombies have no inner life
     }
 
     /*
@@ -64,7 +76,12 @@
      * @return
      */
     public Serializable get( String cacheName, Serializable key, boolean container )
-    {
+    {        
+        if ( log.isDebugEnabled() )
+        {
+            log.debug( "Zombie get for key [" + key + "] cacheName [" + cacheName + "] container [" + container + "]" );
+        }        
+        // zombies have no inner life
         return null;
     }
 
@@ -74,6 +91,7 @@
      */
     public void remove( String cacheName, Serializable key )
     {
+        // zombies have no inner life
     }
 
     /*
@@ -82,6 +100,7 @@
      */
     public void removeAll( String cacheName )
     {
+        // zombies have no inner life
     }
 
     /*
@@ -90,6 +109,8 @@
      */
     public void dispose( String cacheName )
     {
+        // zombies have no inner life
+        return;
     }
 
     /*
@@ -98,6 +119,8 @@
      */
     public void release()
     {
+        // zombies have no inner life
+        return;
     }
 
 }

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCache.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCache.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCache.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCache.java Sun Feb  5 10:48:38 2006
@@ -65,6 +65,8 @@
 public class CompositeCache
     implements ICache, Serializable
 {
+    private static final long serialVersionUID = -2838097410378294960L;
+
     private final static Log log = LogFactory.getLog( CompositeCache.class );
 
     /**
@@ -190,33 +192,33 @@
      * Put an item into the cache. If it is localOnly, then do no notify remote
      * or lateral auxiliaries.
      * 
-     * @param ce,
+     * @param cacheElement
      *            the ICacheElement
-     * @param localOnly,
+     * @param localOnly
      *            Whether the operation should be restricted to local
      *            auxiliaries.
      * @exception IOException
      */
-    protected synchronized void update( ICacheElement ce, boolean localOnly )
+    protected synchronized void update( ICacheElement cacheElement, boolean localOnly )
         throws IOException
     {
 
         // not thread safe, but just for debugging and testing.
         updateCount++;
         
-        if ( ce.getKey() instanceof String && ce.getKey().toString().endsWith( CacheConstants.NAME_COMPONENT_DELIMITER ) )
+        if ( cacheElement.getKey() instanceof String && cacheElement.getKey().toString().endsWith( CacheConstants.NAME_COMPONENT_DELIMITER ) )
         {
             throw new IllegalArgumentException( "key must not end with " + CacheConstants.NAME_COMPONENT_DELIMITER
                 + " for a put operation" );
         }
-        else if ( ce.getKey() instanceof GroupId )
+        else if ( cacheElement.getKey() instanceof GroupId )
         {
             throw new IllegalArgumentException( "key cannot be a GroupId " + " for a put operation" );
         }
 
         log.debug( "Updating memory cache" );
 
-        memCache.update( ce );
+        memCache.update( cacheElement );
 
         // Updates to all auxiliary caches -- remote and laterals, can add as
         // many of each
@@ -257,20 +259,20 @@
             {
                 if ( log.isDebugEnabled() )
                 {
-                    log.debug( "ce.getElementAttributes().getIsRemote() = " + ce.getElementAttributes().getIsRemote() );
+                    log.debug( "ce.getElementAttributes().getIsRemote() = " + cacheElement.getElementAttributes().getIsRemote() );
                 }
 
-                if ( ce.getElementAttributes().getIsRemote() && !localOnly )
+                if ( cacheElement.getElementAttributes().getIsRemote() && !localOnly )
                 {
                     try
                     {
                         // need to make sure the group cache understands that
                         // the
                         // key is a group attribute on update
-                        aux.update( ce );
+                        aux.update( cacheElement );
                         if ( log.isDebugEnabled() )
                         {
-                            log.debug( "Updated remote store for " + ce.getKey() + ce );
+                            log.debug( "Updated remote store for " + cacheElement.getKey() + cacheElement );
                         }
                     }
                     catch ( IOException ex )
@@ -289,7 +291,7 @@
                 {
                     log.debug( "lateralcache in aux list: cattr " + cacheAttr.getUseLateral() );
                 }
-                if ( cacheAttr.getUseLateral() && ce.getElementAttributes().getIsLateral() && !localOnly )
+                if ( cacheAttr.getUseLateral() && cacheElement.getElementAttributes().getIsLateral() && !localOnly )
                 {
                     // later if we want a multicast, possibly delete abnormal
                     // broadcaster
@@ -297,10 +299,10 @@
                     // Currently always multicast even if the value is
                     // unchanged,
                     // just to cause the cache item to move to the front.
-                    aux.update( ce );
+                    aux.update( cacheElement );
                     if ( log.isDebugEnabled() )
                     {
-                        log.debug( "updated lateral cache for " + ce.getKey() );
+                        log.debug( "updated lateral cache for " + cacheElement.getKey() );
                     }
                 }
             }
@@ -359,6 +361,7 @@
                 }
                 catch ( Exception oee )
                 {
+                    // swallow
                 }
                 if ( log.isDebugEnabled() )
                 {
@@ -788,7 +791,7 @@
     /**
      * Removes all cached items.
      * 
-     * @param localOnly, must pass in false to get remote and lateral aux's updated.  This prevents
+     * @param localOnly  must pass in false to get remote and lateral aux's updated.  This prevents
      * looping.
      * @throws IOException
      */

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCacheConfigurator.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCacheConfigurator.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCacheManager.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCacheManager.java Sun Feb  5 10:48:38 2006
@@ -52,6 +52,8 @@
 public class CompositeCacheManager
     implements IRemoteCacheConstants, Serializable, ICompositeCacheManager, ShutdownObservable
 {
+    private static final long serialVersionUID = 7598584393134401756L;
+
     private final static Log log = LogFactory.getLog( CompositeCacheManager.class );
 
     /** Caches managed by this cache manager */
@@ -114,11 +116,20 @@
         return instance;
     }
 
+    /**
+     * Initializes the cache manager using the props file for the given name.
+     * 
+     * @param propsFilename
+     * @return CompositeCacheManager configured from the give propsFileName
+     */
     public static synchronized CompositeCacheManager getInstance( String propsFilename )
     {
         if ( instance == null )
         {
-            log.debug( "Instance is null, creating with default config" );
+            if ( log.isInfoEnabled() )
+            {
+                log.info( "Instance is null, creating with default config [" + propsFilename + "]" );                
+            }
 
             instance = createInstance();
 
@@ -140,8 +151,11 @@
     {
         if ( instance == null )
         {
-            log.debug( "Instance is null, creating with provided config" );
-
+            if ( log.isInfoEnabled() )
+            {
+                log.info( "Instance is null, creating with provided config" );
+            }
+            
             instance = createInstance();
         }
 
@@ -351,7 +365,7 @@
     /** Gets the cache attribute of the CacheHub object 
      * @param cacheName
      * @param cattr
-     * @return*
+     * @return
      */
     public CompositeCache getCache( String cacheName, ICompositeCacheAttributes cattr )
     {
@@ -368,7 +382,7 @@
     public CompositeCache getCache( String cacheName, ICompositeCacheAttributes cattr, IElementAttributes attr )
     {
         cattr.setCacheName( cacheName );
-        return getCache( cattr, this.defaultElementAttr );
+        return getCache( cattr, attr );
     }
 
     /** Gets the cache attribute of the CacheHub object 
@@ -395,6 +409,11 @@
     public CompositeCache getCache( ICompositeCacheAttributes cattr, IElementAttributes attr )
     {
         CompositeCache cache;
+        
+        if ( log.isDebugEnabled() )
+        {
+            log.debug( "attr = " + attr );
+        }
 
         synchronized ( caches )
         {

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/AbstractMemoryCache.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/AbstractMemoryCache.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/AbstractMemoryCache.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/AbstractMemoryCache.java Sun Feb  5 10:48:38 2006
@@ -42,6 +42,10 @@
 
 /**
  * Some common code for the LRU and MRU caches.
+ * <p>
+ * This keeps a static reference to a memory shrinker clock daemon. If this
+ * region is configured to use the shrinker, the clock daemon will be setup to
+ * run the shrinker on this region.
  * 
  * @version $Id$
  */
@@ -50,6 +54,9 @@
 {
     private final static Log log = LogFactory.getLog( AbstractMemoryCache.class );
 
+    private static final int DEFAULT_CHUNK_SIZE = 2;
+
+    /** The region name. This defines a namespace of sorts. */
     protected String cacheName;
 
     /**
@@ -72,11 +79,11 @@
      */
     protected CompositeCache cache;
 
-    // status
+    /** status */
     protected int status;
 
-    // make configurable
-    protected int chunkSize = 2;
+    /** How many to spool at a time. TODO make configurable */
+    protected int chunkSize = DEFAULT_CHUNK_SIZE;
 
     /**
      * The background memory shrinker, one for all regions.
@@ -229,7 +236,6 @@
     public int getStatus()
     {
         return this.status;
-        //return this.STATUS_ALIVE;
     }
 
     /**
@@ -291,8 +297,8 @@
      * @return The cache value
      */
     public CompositeCache getCompositeCache()
-    { 
-        return this.cache; 
+    {
+        return this.cache;
     }
 
     public Set getGroupKeys( String groupName )
@@ -319,7 +325,7 @@
      * Allows us to set the daemon status on the clockdaemon
      * 
      * @author aaronsm
-     *  
+     * 
      */
     class MyThreadFactory
         implements ThreadFactory

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/lru/LRUMemoryCache.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/lru/LRUMemoryCache.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/lru/LRUMemoryCache.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/lru/LRUMemoryCache.java Sun Feb  5 10:48:38 2006
@@ -59,16 +59,18 @@
 public class LRUMemoryCache
     extends AbstractMemoryCache
 {
+    private static final long serialVersionUID = 6403738094136424201L;
+
     private final static Log log = LogFactory.getLog( LRUMemoryCache.class );
 
     // double linked list for lru
     private DoubleLinkedList list;
 
-    int hitCnt = 0;
+    private int hitCnt = 0;
 
-    int missCnt = 0;
+    private int missCnt = 0;
 
-    int putCnt = 0;
+    private int putCnt = 0;
 
     /**
      * For post reflection creation initialization.
@@ -107,7 +109,7 @@
             addFirst( ce );
             // this must be synchronized
             old = (MemoryElementDescriptor) map.put( ( (MemoryElementDescriptor) list.getFirst() ).ce.getKey(),
-                                                     (MemoryElementDescriptor) list.getFirst() );
+                                                     list.getFirst() );
             // If the node was the same as an existing node, remove it.
             if ( old != null && ( (MemoryElementDescriptor) list.getFirst() ).ce.getKey().equals( old.ce.getKey() ) )
             {
@@ -401,6 +403,12 @@
         }
     }
 
+    /**
+     * 
+     *
+     * @author Aaron Smuts
+     *
+     */
     public class MapEntryWrapper
         implements Map.Entry
     {

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/mru/MRUMemoryCache.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/mru/MRUMemoryCache.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/mru/MRUMemoryCache.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/mru/MRUMemoryCache.java Sun Feb  5 10:48:38 2006
@@ -47,23 +47,25 @@
 public class MRUMemoryCache
     extends AbstractMemoryCache
 {
+    private static final long serialVersionUID = 5013101678192336129L;
+
     private final static Log log = LogFactory.getLog( MRUMemoryCache.class );
 
-    int hitCnt = 0;
+    private int hitCnt = 0;
 
-    int missCnt = 0;
+    private int missCnt = 0;
 
-    int putCnt = 0;
+    private int putCnt = 0;
 
     /**
      * Object to lock on the Field
      */
-    protected int[] lockMe = new int[0];
+    private int[] lockMe = new int[0];
 
     /**
      * MRU list.
      */
-    protected LinkedList mrulist = new LinkedList();
+    private LinkedList mrulist = new LinkedList();
 
     /**
      * For post reflection creation initialization
@@ -234,11 +236,7 @@
                 log.debug( "ce =" + ce );
             }
 
-            if ( ce == null )
-            {
-
-            }
-            else
+            if ( ce != null )
             {
                 found = true;
                 ce.getElementAttributes().setLastAccessTimeNow();
@@ -257,7 +255,6 @@
 
         try
         {
-
             if ( !found )
             {
                 // Item not found in cache.

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/DoubleLinkedList.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/DoubleLinkedList.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/DoubleLinkedList.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/DoubleLinkedList.java Sun Feb  5 10:48:38 2006
@@ -10,7 +10,7 @@
 {
 
     // record size to avoid having to iterate
-    int size = 0;
+    private int size = 0;
 
     private final static Log log = LogFactory.getLog( DoubleLinkedList.class );
 
@@ -19,8 +19,13 @@
 
     private DoubleLinkedListNode last;
 
+    /**
+     * Default constructor.
+     *
+     */
     public DoubleLinkedList()
     {
+        super();
     }
 
     /**
@@ -244,7 +249,7 @@
         log.debug( "dumping Entries" );
         for ( DoubleLinkedListNode me = first; me != null; me = me.next )
         {
-            log.debug( "dump Entries> payload= '" + me.payload + "'" );
+            log.debug( "dump Entries> payload= '" + me.getPayload() + "'" );
         }
     }
 

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/DoubleLinkedListNode.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/DoubleLinkedListNode.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/DoubleLinkedListNode.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/DoubleLinkedListNode.java Sun Feb  5 10:48:38 2006
@@ -26,7 +26,9 @@
 public class DoubleLinkedListNode
     implements Serializable
 {
-    Object payload;
+    private static final long serialVersionUID = -1114934407695836097L;
+
+    private Object payload;
 
     /** Double Linked list references */
     public DoubleLinkedListNode prev;
@@ -34,6 +36,10 @@
     /** Double Linked list references */
     public DoubleLinkedListNode next;
 
+    /**
+     * 
+     * @param payloadP
+     */
     public DoubleLinkedListNode( Object payloadP )
     {
         payload = payloadP;

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/MemoryElementDescriptor.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/MemoryElementDescriptor.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/MemoryElementDescriptor.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/util/MemoryElementDescriptor.java Sun Feb  5 10:48:38 2006
@@ -25,6 +25,8 @@
     extends DoubleLinkedListNode
 {
 
+    private static final long serialVersionUID = -1905161209035522460L;
+
     /** The CacheElement wrapped by this descriptor */
     public ICacheElement ce;
 

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/stats/CacheStats.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/stats/CacheStats.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/stats/CacheStats.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/stats/CacheStats.java Sun Feb  5 10:48:38 2006
@@ -32,6 +32,7 @@
     extends Stats
     implements ICacheStats
 {
+    private static final long serialVersionUID = 529914708798168590L;
 
     private String regionName = null;
 

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/stats/Stats.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/stats/Stats.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/stats/Stats.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/stats/Stats.java Sun Feb  5 10:48:38 2006
@@ -26,6 +26,7 @@
 public class Stats
     implements IStats
 {
+    private static final long serialVersionUID = 227327902875154010L;
 
     private IStatElement[] stats = null;
 

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/utils/config/IUtilConstants.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/utils/config/IUtilConstants.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/utils/config/IUtilConstants.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/utils/config/IUtilConstants.java Sun Feb  5 10:48:38 2006
@@ -70,6 +70,7 @@
                     }
                     catch ( IOException ignore )
                     {
+                        // swallow
                     }
                 }
             }
@@ -77,9 +78,10 @@
             ADMIN_PASSWORD = props.getProperty( "admin.password", "system" );
         }
 
-        /** Constructor for the Config object */
+        /** No instances please. */
         private Config()
         {
+            super();
         }
     }
 }

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/utils/data/PropertyGroups.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/utils/data/PropertyGroups.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/utils/data/PropertyGroups.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/utils/data/PropertyGroups.java Sun Feb  5 10:48:38 2006
@@ -38,6 +38,7 @@
 public class PropertyGroups
     extends Hashtable
 {
+    private static final long serialVersionUID = -8722890143331210706L;
 
     private Properties props = null;
 

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/utils/props/PropertyLoader.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/utils/props/PropertyLoader.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/utils/props/PropertyLoader.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/utils/props/PropertyLoader.java Sun Feb  5 10:48:38 2006
@@ -132,6 +132,7 @@
                 }
                 catch ( Throwable ignore )
                 {
+                    // swallow
                 }
         }
 
@@ -156,8 +157,13 @@
         return loadProperties( name, Thread.currentThread().getContextClassLoader() );
     }
 
+    /**
+     * Can't use this one.
+     *
+     */
     private PropertyLoader()
     {
+        super();
     } // this class is not extentible
 
 }

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/utils/struct/LRUElementDescriptor.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/utils/struct/LRUElementDescriptor.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/utils/struct/LRUElementDescriptor.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/utils/struct/LRUElementDescriptor.java Sun Feb  5 10:48:38 2006
@@ -4,11 +4,13 @@
 
 /**
  * @author aaronsm
- *  
+ * 
  */
 public class LRUElementDescriptor
     extends DoubleLinkedListNode
 {
+
+    private static final long serialVersionUID = 8249555756363020156L;
 
     /**
      * <code>key</code>

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/PoolConfiguration.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/PoolConfiguration.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/PoolConfiguration.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/PoolConfiguration.java Sun Feb  5 10:48:38 2006
@@ -85,6 +85,13 @@
     public PoolConfiguration( boolean useBoundary, int boundarySize, int maximumPoolSize, int minimumPoolSize,
                              int keepAliveTime, String whenBlockedPolicy, int startUpSize )
     {
+        setUseBoundary( useBoundary ) ;
+        setBoundarySize( boundarySize );
+        setMaximumPoolSize( maximumPoolSize );
+        setMinimumPoolSize( minimumPoolSize );
+        setKeepAliveTime( keepAliveTime );
+        setWhenBlockedPolicy( whenBlockedPolicy );
+        setStartUpSize( startUpSize );
     }
 
     /**

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/ThreadPool.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/ThreadPool.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/ThreadPool.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/ThreadPool.java Sun Feb  5 10:48:38 2006
@@ -47,6 +47,11 @@
         return queue;
     }
 
+    /**
+     * 
+     * @param run
+     * @throws InterruptedException
+     */
     public void execute( Runnable run )
         throws InterruptedException
     {

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/ThreadPoolManager.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/ThreadPoolManager.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/ThreadPoolManager.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/ThreadPoolManager.java Sun Feb  5 10:48:38 2006
@@ -246,7 +246,7 @@
             Iterator it = names.iterator();
             while ( it.hasNext() )
             {
-                poolNames.add( (String) it.next() );
+                poolNames.add( it.next() );
             }
         }
         return poolNames;

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/behavior/IPoolConfiguration.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/behavior/IPoolConfiguration.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/behavior/IPoolConfiguration.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/utils/threadpool/behavior/IPoolConfiguration.java Sun Feb  5 10:48:38 2006
@@ -6,15 +6,19 @@
  */
 public interface IPoolConfiguration
 {
-
+    /** abort when queue is full and max threads is reached. */
     public static final String POLICY_ABORT = "ABORT";
 
+    /** block when queue is full and max threads is reached. */
     public static final String POLICY_BLOCK = "BLOCK";
 
+    /** run in current thread when queue is full and max threads is reached. */
     public static final String POLICY_RUN = "RUN";
 
+    /** wait when queue is full and max threads is reached. */
     public static final String POLICY_WAIT = "WAIT";
 
+    /** discard oldest when queue is full and max threads is reached. */
     public static final String POLICY_DISCARDOLDEST = "DISCARDOLDEST";
 
     /**

Added: jakarta/jcs/trunk/src/scripts/remoteCacheStats.sh
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/scripts/remoteCacheStats.sh?rev=375078&view=auto
==============================================================================
--- jakarta/jcs/trunk/src/scripts/remoteCacheStats.sh (added)
+++ jakarta/jcs/trunk/src/scripts/remoteCacheStats.sh Sun Feb  5 10:48:38 2006
@@ -0,0 +1,28 @@
+#! /bin/sh
+
+export CLASSPATH=.
+export CLASSPATH=${CLASSPATH}:`dirname $0`/../conf:/usr/java/jcs/conf:/usr/java/jcs/conf/
+
+THISDIR=`dirname $0`
+
+for i in `find ${THISDIR}/../lib -name "*.jar" `
+do
+        export CLASSPATH=${CLASSPATH}:$i
+done
+echo "Classpath = ${CLASSPATH}"
+
+
+POLICY="-Djava.security.policy=`dirname $0`/../conf/cache.policy"
+
+HEAP="-Xms10m -Xmx20m"
+
+DEBUG="-verbose:gc -XX:+PrintTenuringDistribution"
+
+ARGS="$HEAP $DEBUG $POLICY"
+
+echo $ARGS
+
+java  $ARGS org.apache.jcs.auxiliary.remote.server.RemoteCacheServerFactory -stats "$1"
+
+
+

Modified: jakarta/jcs/trunk/src/test-conf/log4j.properties
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/test-conf/log4j.properties?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/test-conf/log4j.properties (original)
+++ jakarta/jcs/trunk/src/test-conf/log4j.properties Sun Feb  5 10:48:38 2006
@@ -2,12 +2,12 @@
 
 log4j.category.org.apache.jcs=INFO
 log4j.category.org.apache.jcs.config=INFO
-log4j.category.org.apache.jcs.engine.INFO
+log4j.category.org.apache.jcs.engine=INFO
 log4j.category.org.apache.jcs.engine.CacheEventQueueFactory=INFO
 log4j.category.org.apache.jcs.auxiliary.disk=INFO
 log4j.category.org.apache.jcs.auxiliary.remote=INFO
 log4j.category.org.apache.jcs.auxiliary.lateral=INFO
-log4j.category.org.apache.jcs.utils.struct=DEBUG
+log4j.category.org.apache.jcs.utils.struct=INFO
 log4j.category.org.apache.jcs.utils.threadpool=INFO
 
 log4j.appender.stdout=org.apache.log4j.ConsoleAppender



---------------------------------------------------------------------
To unsubscribe, e-mail: jcs-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: jcs-dev-help@jakarta.apache.org
--- jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCacheConfigurator.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCacheConfigurator.java Sun Feb  5 10:48:38 2006
@@ -428,16 +428,23 @@
     /**
      * Get an aux cache for the listed aux for a region.
      * 
      * @param cache
      * @param props
      * @param auxName
      * @param regName
      * @return AuxiliaryCache
      */
     protected AuxiliaryCache parseAuxiliary( CompositeCache cache, Properties props, String auxName, String regName )
     {
         AuxiliaryCache auxCache;
 
+        if ( log.isDebugEnabled() )
+        {
+            // cache isn't used.
+            // TODO change method signature if is isn't needed.
+            log.debug( "parseAuxiliary, Cache = " + cache );
+        }
+        
         // GET FACTORY
         AuxiliaryCacheFactory auxFac = compositeCacheManager.registryFacGet( auxName );
         if ( auxFac == null )
@@ -428,16 +428,23 @@
      * Get an aux cache for the listed aux for a region.
      * 
-     * @param cache
-     * @param props
-     * @param auxName
-     * @param regName
+     * @param cache the cache manager
+     * @param props the configuration propeties
+     * @param auxName the name of the auxiliary cache
+     * @param regName the name of the region.
      * @return AuxiliaryCache
      */

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCacheManager.java
URL: http://svn.apache.org/viewcvs/jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCacheManager.java?rev=375078&r1=375077&r2=375078&view=diff
==============================================================================